package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````_)@$"#0```!LL@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(O*L`
M`+RK```%`````!````$```#XK@``^#X%"/@^!0@X`@``?!(```8`````$```
M`@````2O```$/P4(!#\%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&2`I0``@"4%"(`E!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D^*X`
M`/@^!0CX/@4("`$```@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```!@````$````%`````,```!'
M3E4`%TJD79WA[.I$;0M.*-+-*G]<%[HE````1@````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$"`A&````2```````````````````
M`$H```!,````30````````!.````3P```%$```!2````4P```%0`````````
M5@``````````````5P```%@```!;``````````````!<````7@```%\```!A
M`````````&,```!E``````````````!G````:````&D`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSZ
MH6Q@N8WQ#@````````````````````#O`@`````````````2````E0,`````
M````````$@```"P"`````````````!(````1```````````````@`````P0`
M````````````$@```(8#`````````````!(```!4`0`````````````2````
M"@,`````````````$@```-,``````````````!(```#V`@`````````````2
M````KP``````````````$@```$\!`````````````!(```"F`@``````````
M```2````0P,`````````````$@```+<"`````````````!(```"X`0``````
M```````2````4P,`````````````$@```$H#`````````````!(```!X`0``
M```````````2````X0``````````````$@````("`````````````!(```"?
M`0`````````````2````=0(`````````````$@```"0"`````````````!(`
M``#3`@`````````````2````[P$`````````````$@```,0"````````````
M`!(```#[`0`````````````2````A@$`````````````$@```%H#````````
M`````!(````M```````````````@````AP(`````````````$@```&<#````
M`````````!(```!X```````````````2````X0(`````````````$@```)P#
M`````````````!(````=`@`````````````2````#P$`````````````$@``
M`+X``````````````!(```"M`0`````````````2````Z`(`````````````
M$@```+X"`````````````!(```"4`@`````````````2````10(`````````
M````$@```,P"`````````````!(```!J```````````````2````60$`````
M````````$@```!$#`````````````!(```#D`0`````````````2````'`$`
M````````````$@```(X#`````````````!(````X`0`````````````2````
MV@(`````````````$@```,8!`````````````!(````\```````````````@
M````\P``````````````$@```)8!`````````````!(```!N`P``````````
M```2````_`(`````````````$@```(<``````````````!(```!0````````
M```````@````C`(`````````````$@```#(#`````````````!(````Q`@``
M```````````2````'P,`````````````$@```%8"`````````````!(```"=
M`@`````````````2````*@,`````````````$@```'@#`````````````!(`
M``!E`0``@)4$"``````2````>P0``#CF!`@$````$0`/`#$$````U`0(G0P`
M`!(`#0""!```L-`$"*\!```2``T`V@,``"3F!`@`````$@`.`+`#``!`004(
M!````"$`&0#@`P``P,T$"`4````2``T`800``+#E!`AA````$@`-`)X```!`
ME@0(`````!(````M`0``2$$%"`0````1`!D`/@0``"!!!0@`````$``8`#P#
M``!$004(!````!$`&0!`!```($$%"``````@`!@`KP,``$!!!0@$````(0`9
M`-`#```@Y@0(`@```!(`#0!Q!```+$$%"`0````1`!@`EP0``-#-!`C(`0``
M$@`-``(!``!,004(`0```!$`&0"N`P``0$$%"`0````1`!D`J0,``""7!`C<
M`0``$@`-`+8$``!@T@0(1````!(`#0#Q`P``L-($""0````2``T`#`0``+#D
M!`AH````$@`-`+\#```P004(`````!``&0#+`P``=%$%"``````0`!D`9@(`
M`#SF!`@$````$0`/`.`$``"@X`0("P0``!(`#0!+!```\,P$",$````2``T`
M1`0``/R8!`@`````$@`-`-0!``!0DP0(`````!(````E!```T,\$".`````2
M``T`N`,``#!!!0@`````$``8`!@$``"@SP0((@```!(`#0#$!```(.4$"$D`
M```2``T`CP0``%#,!`@T````$@`-`*0$``#@T@0($@$``!(`#0"1!```F)($
M"``````2``L``&QI8G!E<FPN<V\N-2XQ.`!?251-7V1E<F5G:7-T97)434-L
M;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?
M879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H
M<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P
M97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E
M<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;&EB<'1H
M<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H<F5A9%]G971S<&5C
M:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N<V\N-@!?24]?<W1D
M:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D
M=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T
M<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?
M;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D
M;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB
M8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M
M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]F<%]H=P!P87)?:6YI
M=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)0D-?
M,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````@`"``,````"``(``@`"
M`````@``````!``"``(````"``(````````````%``8``@````(``@````<`
M```"``(````"``(`!@`````````"``(``@`#``(```````<```````(````"
M````````````"``'```````"``@``P`(``,``@`"``<````!``$``0`!``(`
M`0`!```````!``(``0`"``$``0`!`````@`!``$``0`!``$``0`!``$``0`!
M`````0`!``$``0`!``$``0````$``@`-`@``$````#`````2:6D-```&`/8$
M```0````$&EI#0```P``!0````````$`!0!<`@``$``````````2:6D-```(
M`/8$```0````=!EI"0``!P`*!0``$````'(9:0D```4`%@4``!`````4:6D-
M```$`"(%```0````$&EI#0```@``!0```````/P_!0@&'P``0$$%"`58``!$
M004(!5$``$A!!0@%3P``3$$%"`57```,0`4(!P$``!!`!0@'`@``%$`%"`<#
M```80`4(!P4``!Q`!0@'!@``($`%"`<'```D0`4(!P@``"A`!0@'"0``+$`%
M"`=C```P0`4(!PH``#1`!0@'"P``.$`%"`<,```\0`4(!PT``$!`!0@'#@``
M1$`%"`</``!(0`4(!Q```$Q`!0@'$0``4$`%"`<2``!40`4(!Q,``%A`!0@'
M%```7$`%"`<5``!@0`4(!Q8``&1`!0@'%P``:$`%"`<8``!L0`4(!QD``'!`
M!0@'&@``=$`%"`<;``!X0`4(!QP``'Q`!0@''0``@$`%"`<>``"$0`4(!Q\`
M`(A`!0@'(```C$`%"`<A``"00`4(!R(``)1`!0@'(P``F$`%"`<D``"<0`4(
M!R4``*!`!0@')@``I$`%"`<G``"H0`4(!R@``*Q`!0@'*0``L$`%"`<J``"T
M0`4(!RL``+A`!0@'1@``O$`%"`<L``#`0`4(!RT``,1`!0@'+@``R$`%"`<O
M``#,0`4(!S```-!`!0@',0``U$`%"`<R``#80`4(!S,``-Q`!0@'-```X$`%
M"`<U``#D0`4(!S8``.A`!0@'3@``[$`%"`<X``#P0`4(!SD``/1`!0@'.@``
M^$`%"`<[``#\0`4(!SP```!!!0@'/@``!$$%"`<_```(004(!T````Q!!0@'
M00``$$$%"`="```4004(!T,``!A!!0@'1```'$$%"`=%``!3@^P(Z'\&``"!
MPU^M``"+@_S___^%P'0%Z/H!``"#Q`A;PP``````_S4$0`4(_R4(0`4(````
M`/\E#$`%"&@`````Z>#_____)1!`!0AH"````.G0_____R440`4(:!````#I
MP/____\E&$`%"&@8````Z;#_____)1Q`!0AH(````.F@_____R4@0`4(:"@`
M``#ID/____\E)$`%"&@P````Z8#_____)2A`!0AH.````.EP_____R4L0`4(
M:$````#I8/____\E,$`%"&A(````Z5#_____)31`!0AH4````.E`_____R4X
M0`4(:%@```#I,/____\E/$`%"&A@````Z2#_____)4!`!0AH:````.D0____
M_R5$0`4(:'````#I`/____\E2$`%"&AX````Z?#^____)4Q`!0AH@````.G@
M_O___R500`4(:(@```#IT/[___\E5$`%"&B0````Z<#^____)5A`!0AHF```
M`.FP_O___R5<0`4(:*````#IH/[___\E8$`%"&BH````Z9#^____)61`!0AH
ML````.F`_O___R5H0`4(:+@```#I</[___\E;$`%"&C`````Z6#^____)7!`
M!0AHR````.E0_O___R5T0`4(:-````#I0/[___\E>$`%"&C8````Z3#^____
M)7Q`!0AHX````.D@_O___R6`0`4(:.@```#I$/[___\EA$`%"&CP````Z0#^
M____)8A`!0AH^````.GP_?___R6,0`4(:``!``#IX/W___\ED$`%"&@(`0``
MZ=#]____)91`!0AH$`$``.G`_?___R680`4(:!@!``#IL/W___\EG$`%"&@@
M`0``Z:#]____):!`!0AH*`$``.F0_?___R6D0`4(:#`!``#I@/W___\EJ$`%
M"&@X`0``Z7#]____):Q`!0AH0`$``.E@_?___R6P0`4(:$@!``#I4/W___\E
MM$`%"&A0`0``Z4#]____);A`!0AH6`$``.DP_?___R6\0`4(:&`!``#I(/W_
M__\EP$`%"&AH`0``Z1#]____)<1`!0AH<`$``.D`_?___R7(0`4(:'@!``#I
M\/S___\ES$`%"&B``0``Z>#\____)=!`!0AHB`$``.G0_/___R740`4(:)`!
M``#IP/S___\EV$`%"&B8`0``Z;#\____)=Q`!0AHH`$``.F@_/___R7@0`4(
M:*@!``#ID/S___\EY$`%"&BP`0``Z8#\____)>A`!0AHN`$``.EP_/___R7L
M0`4(:,`!``#I8/S___\E\$`%"&C(`0``Z5#\____)?1`!0AHT`$``.E`_/__
M_R7X0`4(:-@!``#I,/S___\E_$`%"&C@`0``Z2#\____)0!!!0AHZ`$``.D0
M_/___R4$004(:/`!``#I`/S___\E"$$%"&CX`0``Z?#[____)0Q!!0AH``(`
M`.G@^____R40004(:`@"``#IT/O___\E%$$%"&@0`@``Z<#[____)1A!!0AH
M&`(``.FP^____R4<004(:"`"``#IH/O__U6)Y593@^3P@^PPC440B40D"(U%
M#(E$)`2-10B)!"3HG/W__\=$)`B`E00(QT0D!("5!`C'!"1`E@0(Z!!.``"`
M/4Q!!0@`=2[HHOS__X7`HW!1!0@/A'4!``")!"3H[?O__Z%(004(B00DZ##_
M___&@%D%````H4A!!0B)!"3H'/___X"(!@,```*A2$$%"(D$).@(____,=*`
MB`8#```!BT4(B50D'(U(!8E,)!C?;"08V`5T)04(W05X)04(V<G?Z=W8#X<`
M`0``P>$"B0PDZ&K\__^+=0R+70C'!6A1!0@$````BQ:#^P&C9%$%",=`!"7H
M!`B)$(L5+$$%",=`#"CH!`B)4`BZ`0```'X.BPR6B4R0#(/"`3G:=?+'1)@,
M`````(/#`XE$)`RA<%$%"(E<)`C'1"00`````,=$)`20S`0(B00DZ'+]__^%
MP(G#=#JA<%$%"(D$).@_^___C50D++CIY@0(Z-$L``"%P'0LH7!1!0B)!"3H
MX/K__^@+_?__C67XB=A;7EW#H7!1!0B)!"3HI?W__XG#Z[6A;%$%"(7`=`J)
M!"3HX$L``.O!C50D++B>Y@0(Z(`L``"%P*-L404(=*KKW>@@_?__QP0D`0``
M`.C$^___,>U>B>&#Y/!05%)H(.8$"&BPY00(459H()<$".CC^___]&:0BQPD
MPV:09I!FD&:09I!FD+@S004(+3!!!0B#^`9W`<.X`````(7`=/95B>6#[!C'
M!"0P004(_]#)PXVV`````+@P004(+3!!!0C!^`*)PL'J'P'0T?AU`<.Z````
M`(72=/95B>6#[!B)1"0$QP0D,$$%"/_2R<.)]HV\)P````"`/4U!!0@`=1-5
MB>6#[`CH?/___\8%34$%"`')\\-FD*$`/P4(A<!T'[@`````A<!T%E6)Y8/L
M&,<$)``_!0C_T,GI>?___Y#I<____V:0D%4QR5=64X'L[`(``(E$)%B#P#B)
M;"0$B<6)/"2-="8`BW2-`(M\C03'1,QL`````,=$S'0`````B?#!X`B)^HG#
MB?#!X!B!XP``_P`)PXGP#ZS0"(GZ)0#_```)PXGP#ZS0&(G^)?\````Q_PG#
MB?#!X`B)^HE<S&B)PXGPP>`8@>,``/\`"<.)\`^LT`@E`/\```^L_A@)PX'F
M_P````GSB5S,<(/!`H/Y$`^%;____XVT)-````")]8VV`````(M=V(V\)-`"
M``"#Q0@S7?B+3=0S7:`S79`S3?PS3:0S392)WL=%%``````/K,X?B=D!V0GQ
MB4T0.?UUQ(M$)%B+>`B+<!"+$(M8&(D\)(MX%(M(!(ET)`B+<!R)7"10B=.+
M:`R)?"0,BW@@B4PD-(ET)%2);"0$BV@DB7PD8(L$)`-\)&B)5"0PB6PD9(''
MF7F"6@^LRQN)T8E<)!"+="00P>$%B</WTPG.`?>+="0((UPD4"'&B70D$(MT
M)`PC="0$B70D&(MT)!`)W@'WB7PD$(L$)(M4)`3'1"04`````,=$)"0`````
MB<,/K-,"BU0D-,'@'HG>BUPD4`G&BT0D,(ET)""+="14`UPD</?2$W0D=(G!
MB5PD*/?1BUPD$(ET)"R+="0@@40D*)EY@EJ#5"0L`"-,)`@AQ@G.B=F)\(MT
M)`PAUHG:`40D*!%T)"R+="04P>$%#ZSR&XE4)!B+="08"<X!="0HBW0D*(ET
M)!B+1"0PBU0D-,=$)!P`````QT0D/`````")P0^LT0*+5"0(P>`>B<Z+3"0,
M"<:+1"00`U0D>!-,)'R)="0XB?Z)5"1`]]:)3"1$BTPD((%$)$"9>8):@U0D
M1``QTB'QBW0D."'^B?.)SHM,)!P)W@%T)$`15"1$BU0D&(G6#ZS.&XG!P>(%
M"=:+5"04`70D0#'_P>`>BW0D0`^LT0*)S0G%B6PD2,=$)$P`````BTPD(`.,
M)(````"+7"0D$YPDA````(E,)""+3"08@40D()EY@EJ+1"08B5PD)(M<)"B#
M5"0D`/?1(TPD.#'2QT0D%``````AZPG9BUPD/`%,)"")\1%4)"0/K/D;BU0D
M'(E,)!"+;"00B?'!X07'1"0L``````G-B<$!;"0@BVPD(`^LT0+!X!Z);"00
MB<V+3"0X"<4#C"2(````$YPDC````(EL)"B)3"0XB?&!1"0XF7F"6O?1B5PD
M/(GS@U0D/``AZR-,)$@QTL=$)!P`````QT0D1``````)V8M<)"`!3"0X$50D
M/(M,)!2+5"00#ZS*&XM,)!")5"08BVPD&,'A!0G-B?$!;"0XBVPD.`^L^0+!
MYAZ);"08B<V+3"00"?6+="1(`[0DD````(M4)!CWT8'&F7F"6B'K(TPD*(EL
M)$`)V0'.BTPD'`^LRAN)5"0@BTPD&(ML)""+1"00BU0D%,'A!8M<)#@)S8G!
M`>X/K-$"BU0D*,'@'HG-BTPD+`G%`Y0DF````!.,))P```");"1(B50D*(E,
M)"R+3"08@40D*)EY@EJ#5"0L`"'K,=+WT2-,)$")="0@QT0D)`````")S8M,
M)"0)W0%L)"@15"0LBU0D(,=$)$P`````#ZS*&XG7BU0D((G]P>(%"=4!;"0H
MBVPD*(EL)!"+1"08BU0D'(M<)$3'1"04`````(G!#ZS1`L'@'HG-BTPD0`G%
MBT0D(`.,)*`````3G"2D````B6PD.(E,)$")\8%$)$"9>8):]]&)7"1$BUPD
M%(-4)$0`(>XC3"1(,=+'1"0\``````GQ`4PD0(M,)!`15"1$BU0D),=$)"0`
M````B<X/K-X;P>$%"<Z)P0%T)$`Q_P^LT0*+5"1(P>`>B<V+3"1,"<6+="1`
M`Y0DJ````!.,)*P```");"0@B50D2(M4)!")3"1,BTPD.(M<)"B!1"1(F7F"
M6O?2BT0D$(-4)$P`(=$AZXG-"=TQTHM<)#P!;"1(B?$15"1,B?(/K/H;B50D
M&(ML)!C!X07'1"0<`````,=$)"P`````"<V)P0%L)$B+5"1(P>`>B50D&(M4
M)!0/K-$"B<V+3"0X"<4#C"2P````$YPDM````(EL)"B)3"0XB?&)7"0\]]&)
M\X%$)#B9>8):@U0D/``AZR-,)"`QTL=$)!0`````QT0D1``````)V8M<)$@!
M3"0X$50D/(M,)!R+5"08#ZS*&XM,)!B)5"00BVPD$,'A!0G-B?$!;"0XBVPD
M.`^L^0+!YAZ);"00B<V+3"08"?6+="0@`[0DN````(M4)!#WT8'&F7F"6B'K
M(TPD*(EL)$`)V0'.BTPD%`^LRAN+3"00B50D((ML)"#!X04)S0'NB70D((M$
M)!B+5"0<BUPD.,=$)"0`````B<$/K-$"BU0D*,'@'HG-BTPD+`G%`Y0DP```
M`!.,),0```");"1(B50D*(E,)"R+3"00@40D*)EY@EJ#5"0L`"'K,=+WT2-,
M)$#'1"1,`````(G-BTPD)`G=`6PD*!%4)"R+5"0@#ZS*&XG7BU0D((G]P>(%
M"=4!;"0HBVPD*(EL)!C'1"0<`````(M$)!"+5"04BUPD1,=$)#P`````B<$/
MK-$"P>`>B<V+3"1`"<6+1"0@`XPDR````!.<),P```");"0XB4PD0(GQ@40D
M0)EY@EKWT8E<)$2+7"0<@U0D1``A[B-,)$@QT@GQ`4PD0(M,)!@15"1$BU0D
M),=$)"0`````B<X/K-X;P>$%"<Z)P0%T)$`Q_P^LT0*+5"1(P>`>B<V+3"1,
M"<6+="1``Y0DT````!.,)-0```");"0@B50D2(M4)!B)3"1,BTPD.(M<)"B!
M1"1(F7F"6O?2BT0D&(-4)$P`(=$AZXG-"=TQTHM<)#P!;"1(B?$15"1,B?(/
MK/H;B50D$(ML)!#!X07'1"04`````,=$)"P`````"<V)P0%L)$B+5"1(P>`>
MB50D$(M4)!P/K-$"B<V+3"0X"<4#C"38````$YPDW````(EL)"B)3"0XB?&)
M7"0\]]&)\X%$)#B9>8):@U0D/``AZR-,)"`QTL=$)!P`````QT0D1``````)
MV8M<)$@!3"0X$50D/(M,)!2+5"00#ZS*&XM,)!")5"08BVPD&,'A!0G-B?$!
M;"0XBVPD.`^L^0+!YAZ);"08B<V+3"00"?6+="0@`[0DX````(M4)!CWT8'&
MF7F"6B'K(TPD*(EL)$`)V0'.BTPD'`^LRAN+3"08B50D((ML)"#!X04)S0'N
MB70D((M$)!"+5"04BUPD.,=$)"0`````B<$/K-$"BU0D*,'@'HG-BTPD+`G%
M`Y0DZ````!.,).P```");"1(B50D*(E,)"R+3"08@40D*)EY@EJ#5"0L`"'K
M,=+WT2-,)$#'1"1,`````(G-BTPD)`G=`6PD*!%4)"R+5"0@#ZS*&XG7BU0D
M((G]P>(%"=4!;"0HBVPD*(EL)!#'1"04`````(M$)!B+5"0<BUPD1,=$)!P`
M````B<$/K-$"P>`>B<V+3"1`"<6+1"0@`XPD\````!.<)/0```");"08B4PD
M.(GQ@40D.)EY@EKWT8E<)#R+7"04@U0D/``A[B-,)$@QT@GQ`4PD.(M,)!`1
M5"0\BU0D),=$)"0`````B<X/K-X;P>$%"<Z)P0%T)#@Q_P^LT0*+5"1(P>`>
MB<V+3"1,"<6+="0X`Y0D^````!.,)/P```");"0@B50D0(M4)!")3"1$BTPD
M&(M<)"B!1"1`F7F"6O?2BT0D$(-4)$0`(=$AZXG-"=TQTHM<)!P!;"1`B?$1
M5"1$B?(/K/H;B50D*(ML)"C!X07'1"0L`````,=$)$P`````"<V)P0%L)$"+
M5"1`P>`>B50D*(M4)!0/K-$"B<V+3"08"<4#C"0``0``$YPD!`$``(EL)%R)
M;"1(B4PD$(GQB5PD%/?1B?.!1"00F7F"6H-4)!0`(>LC3"0@,=+'1"0<````
M``G9`4PD$!%4)!2+3"0LBU0D*`^LRAN+3"0HB50D&(ML)!B)\L'A!0G-`6PD
M$`^L^@*+7"00P>8>BWPD)(GPB=:+5"1<"<:)]8MT)"`#M"0(`0``B5PD&(M<
M)$`3O"0,`0``B70D((%$)""AZ]ENB7PD)(-4)"0`,>HQTS'2`5PD((MT)!B+
M?"0<$50D)(GRB?$/K/H;B50D.(MT)#C!X06+5"0LQT0D/``````)S@%T)""+
M1"0@BW0D$(E$)#B+1"0HB<$/K-$"P>`>B<N+3"1("<.)VHM<)$P#C"00`0``
M$YPD%`$``(E4)$B)3"0HB=&!1"0HH>O9;HE<)"R#5"0L`#'I,<XQT@%T)"@1
M5"0LBW0D.(M\)#R+1"08QT0D1`````")\HGQ#ZSZ&XE4)!"+="00P>$%BU0D
M',=$)"0`````"<Z)P0%T)"@/K-$"BW0D*(G+BXPD&`$``,'@'HM4)$0)PXET
M)$"+="0@@<&AZ]ENBT0D0`'IBVPD2(E<)%R)QS'=,>X!\8G&BT0D.`^LUQN+
M5"0\B7PD$(ML)!#!Y@4)]8G&`>D/K-8"BY0D)`$``,'@'HGU"<6+A"0@`0``
MB4PD((E4)!2)1"00BT0D2(%$)!"AZ]EN@U0D%``QT@%$)!`15"04BU0D7(MT
M)"B+?"0DQT0D+``````QZC'6,=(!="00BW0D(!%4)!2)\`^L^!N+?"1$B40D
M&(GPBW0D&,'@!8E$)"@+="0H`70D$(M$)!"+="1`B40D*(GP#ZSX`HE$)!B+
M5"08B?#!X!X)PHN$)"@!``")UHN4)"P!``")1"08@40D&*'KV6Z)5"0<@U0D
M'``QTHM$)%P!1"08$50D'(GR,>J+?"0LB70D0(G6,=(QSHM$)"`!="08BW0D
M*!%4)!S'1"0\`````(GRB?$/K/H;B50D.(MT)#C!X06+5"0D"<Z)P0%T)!B+
M="08#ZS1`HG+BXPD,`$``(M4)$#!X!X)PXET)#B+="00@<&AZ]ENBT0D.`'I
M,=J)7"1(,=:+5"0\B<<!\8G&P>8%#ZS7&XE\)!"+;"00"?4!Z8E,)""+1"0H
MBU0D+,=$)"0`````BWPD)(G&#ZS6`HN4)#P!``#!X!Z)]8MT)!@)Q8N$)#@!
M``")5"04B40D$(M$)$"!1"00H>O9;H-4)!0`,=(!1"00$50D%(M4)$@QZC'6
M,=(!="00BW0D(!%4)!2)\`^L^!N)1"08B?"+="08P>`%B40D*`MT)"@!="00
MBT0D$(E$)"B+="0XBWPD/,=$)"P`````B?`/K/@"BWPD+(E$)!B+5"08B?#!
MX!X)PHN$)$`!``")UHN4)$0!``")="1`B40D&(M$)$B!1"08H>O9;HE4)!R#
M5"0<`#'2`40D&!%4)!R)\C'JB=8QTC'.`70D&(MT)"@15"0<B?*)\0^L^AN)
M5"0XBW0D.,'A!0G.`70D&(MT)!B)="0XBT0D((M4)"2+="00QT0D/`````")
MP0^LT0*+5"1`B<N+C"1(`0``P>`>"<.+1"0XB5PD2('!H>O9;@'I,=HQUHM4
M)#R)QP'QB<:+1"0HP>8%QT0D)``````/K-<;BU0D+(E\)!"+;"00"?6)Q@'I
M#ZS6`HN4)%0!``#!X!Z)]8MT)!@)Q8N$)%`!``")3"0@B50D%(E$)!"+1"1`
M@40D$*'KV6Z#5"04`#'2`40D$!%4)!2+5"1(,>HQUC'2`70D$!%4)!2+="0@
MBWPD),=$)"P`````B?`/K/@;BWPD/(E$)!B)\(MT)!C!X`6)1"0H"W0D*`%T
M)!"+1"00BW0D.(E$)"B)\`^L^`*)1"08BU0D&(GPP>`>"<*+A"18`0``B=:+
ME"1<`0``B70D0(E$)!B+1"1(@40D&*'KV6Z)5"0<@U0D'``QT@%$)!@15"0<
MB?(QZHG6,=(QS@%T)!B+="0HBWPD+!%4)!R+1"0@B?*)\0^L^AN)5"0XBW0D
M.,'A!8M4)"3'1"0\`````,=$)"0`````"<Z)P0%T)!B+="08#ZS1`HG+BXPD
M8`$``(M4)$#!X!X)PXET)#B+="00@<&AZ]ENBT0D.`'I,=J)7"1(,=:+5"0\
MB<<!\8G&BT0D*,'F!0^LUQN+5"0LB7PD$(ML)!`)]8G&`>D/K-8"BY0D;`$`
M`,'@'HGU"<6+A"1H`0``B4PD((E4)!2)1"00@40D$*'KV6Z#5"04`#'2BT0D
M0`%$)!`15"04BU0D2(MT)!B+?"0DQT0D+``````QZC'6,=(!="00BW0D(!%4
M)!2)\`^L^!N+?"0\B40D&(GPBW0D&,'@!8E$)"@+="0H`70D$(M$)!"+="0X
MB40D*(GP#ZSX`HE$)!B+5"08B?#!X!X)PHN$)'`!``")UHN4)'0!``")1"08
MB50D'(M$)$B!1"08H>O9;H-4)!P`,=(!1"08$50D'(GR,>J+?"0LB70D2(G6
M,=(QSHM$)"`!="08BW0D*!%4)!S'1"0\`````(GRB?$/K/H;B50D.(MT)#C!
MX06+5"0D"<Z)P0%T)!B+="08#ZS1`HG+BXPD>`$``(M4)$C!X!X)PXET)#B+
M="00@<&AZ]ENBT0D.`'I,=J)7"0@,=:+5"0\B<<!\8G&P>8%#ZS7&XE\)!"+
M;"00BT0D*(M4)"S'1"1$`````(M\)$0)]8G&`>D/K-8"BY0DA`$``,'@'HGU
MBW0D&`G%BX0D@`$``(E,)$")5"04B40D$(M$)$B!1"00H>O9;H-4)!0`,=(!
M1"00$50D%(M4)"`QZC'6,=(!="00BW0D0!%4)!2)\`^L^!N)1"08B?"+="08
MP>`%B40D*`MT)"@!="00BW0D.(M$)!"+?"0\QT0D+`````")1"0HB?`/K/@"
MBWPD+(E$)!B+5"08B?#!X!X)PHN$)(@!``")UHN4)(P!``")="1(B40D&(M$
M)""!1"08H>O9;HE4)!R#5"0<`#'2`40D&!%4)!R)\C'JB=8QTC'.`70D&(MT
M)"@15"0<B?*)\0^L^AN)5"0@BW0D(,'A!0G.`70D&(M$)$"+5"1$BW0D&,=$
M)"0`````B<$/K-$"BU0D)(G+BXPDD`$``,'@'@G#B70D((MT)!"!P:'KV6Z+
M1"0@`>F+;"1(B5PD0,=$)#P`````B<<QW3'N`?&)QHM$)"@/K-<;BU0D+(E\
M)!"+;"00P>8%QT0D+``````)]8G&`>D/K-8"BU0D0,'@'HGUB[0DF`$```G%
MBT0D2(EL)%R)3"0X@<:AZ]EN`<8QZHML)!B+1"0X,=6+5"0\`>X/K-`;BU0D
M)(E$)!"+1"0XBVPD$,'@!8E$)!B+1"0@"VPD&`'N#ZS0`HN4)*0!``")QXM$
M)"")_8ET)"C!X!X)Q8N$)*`!``")1"00BT0D0(%$)!"AZ]ENB50D%(-4)!0`
M,=(!1"00$50D%(M4)%R);"1(BT0D.,=$)$0`````,>J)U3'2,<V+3"0L`6PD
M$!%4)!2+5"0H#ZS*&XM,)"B)U8M4)#S!X04)S8G!`6PD$`^LT0*+7"00BY0D
MJ`$``(G-BXPDK`$``,'@'@G%B5PD0(E4)!B)3"0<BT0D7(%$)!C<O!N/@U0D
M'``QT@%$)!@15"0<BU0D2(M\)"S'1"0\`````(G1B=,)Z2'K(?$QT@G9`4PD
M&!%4)!R+3"1$BU0D0`^LRAN)UHM4)$#!X@4)UHN4)+0!```!="08BW0D&(E4
M)"2)="0XBW0D*(GQ#ZSY`L'F'HGPB<X)QHN$)+`!``")\8GSB?>)1"0@@40D
M(-R\&X^#5"0D`#'2BT0D2`%$)"`15"0D">DC3"00(>N+1"0X,=+'1"0L````
M``G9`4PD(!%4)"2)P8M4)#P/K-$;BU0D1(E,)!"+="00B<'!X04)S@%T)""+
M1"0@B40D*(M$)$")P0^LT0*+E"2X`0``B<N+C"2\`0``P>`>"<.)5"00@40D
M$-R\&X^)3"04B=F#5"04`#'2`6PD$!%4)!0)^2-,)!@QTHE<)$@A^XM$)#B)
M?"1<B<X)WHM<)"@!="00BW0D+!%4)!2)VHG9BYPDQ`$``,'A!0^L\AN)UHM4
M)#P)SHG!`70D$(MT)!#!X!X/K-$"B<V+C"3``0``"<6+1"1<B5PD'(ET)$")
M3"08@40D&-R\&X^#5"0<`#'2`40D&,=$)$0`````$50D'(M4)$B+?"0LQT0D
M/`````")T8G3">DAZR-,)"`QT@G9`4PD&!%4)!R+5"1`BTPD1(G6#ZS.&\'B
M!0G6BY0DS`$```%T)!B+="08B50D)(ET)#B+="0HB?$/K/D"P>8>B?")S@G&
MBX0DR`$``(GQB?.)]XE$)""+1"1(@40D(-R\&X^#5"0D`#'2`40D(!%4)"0)
MZ2-,)!`AZS'2"=D!3"0@BT0D.!%4)"2+5"0\B7PD7(G!QT0D+``````/K-$;
MBU0D1(E,)!"+="00B<'!X04)S@%T)""+1"0@B40D*(M$)$")P0^LT0*+E"30
M`0``B<N+C"34`0``P>`>"<.)5"00@40D$-R\&X^)3"04B=F#5"04`#'2`6PD
M$!%4)!0)^2-,)!@QTHE<)$@A^XG."=X!="00BUPD*(MT)"P15"04BT0D.(G:
MB=F+G"3<`0``#ZSR&XG6BU0D/,'A!0G.B<$!="00#ZS1`HMT)!")S8N,)-@!
M``#!X!X)Q8M$)%R)7"0<B4PD&(%$)!C<O!N/@U0D'``QT@%$)!@15"0<BU0D
M2(ET)$#'1"1$`````(G1B=,)Z2'K(TPD(#'2"=D!3"08$50D'(M4)$"+3"1$
MBWPD+,=$)#P`````B=8/K,X;P>(%"=:+E"3D`0```70D&(MT)!B)5"0DB70D
M.(MT)"B)\0^L^0+!YAZ)\(G."<:+A"3@`0``B?&)\XGWB40D((M$)$B!1"0@
MW+P;CX-4)"0`,=(!1"0@$50D)`GI(TPD$"'KBT0D.#'2"=D!3"0@$50D)(G!
MBU0D/`^LT1N)3"00BW0D$(G!P>$%BU0D1,=$)"P`````B7PD7`G.`70D((M$
M)"")1"0HBT0D0(G!#ZS1`HN4).@!``")RXN,).P!``#!X!X)PXE4)!"!1"00
MW+P;CXE,)!2)V8-4)!0`,=(!;"00$50D%`GY(TPD&#'2B5PD2"'[B<X)WHM<
M)"@!="00BW0D+!%4)!2)VHG9P>$%#ZSR&XG6"<X!="00BT0D.(M4)#R+G"3T
M`0``BW0D$(G!#ZS1`HG-BXPD\`$``,'@'@G%BT0D7(E<)!R)3"08@40D&-R\
M&X^#5"0<`#'2`40D&!%4)!R+5"1(B70D0,=$)$0`````B=&)TPGI(>LC3"0@
M,=()V0%,)!@15"0<BU0D0(M,)$2)U@^LSAO!X@4)U@%T)!B+="08B70D.(MT
M)"B+?"0LBY0D_`$``,=$)#P`````B?$/K/D"P>8>B?")S@G&BX0D^`$``(E4
M)"2)\8GSB?>)1"0@BT0D2(%$)"#<O!N/@U0D)``QT@%$)"`15"0D">DC3"00
M(>N+1"0X,=()V0%,)"`15"0DB<&+5"0\#ZS1&XE,)!"+="00B<'!X04)S@%T
M)""+1"0@B40D*,=$)"P`````BT0D0(M4)$2)?"1<QT0D1`````")P0^LT0*+
ME"0``@``B<N+C"0$`@``P>`>"<.+1"0XB50D$(%$)!#<O!N/B4PD%(G9@U0D
M%``QT@%L)!`15"04"?DC3"08,=*)7"1((?N)S@G>BUPD*`%T)!"+="0L$50D
M%(G:B=F+G"0,`@``P>$%#ZSR&XG6BU0D/`G.B<$!="00BW0D$,'@'@^LT0*)
MS8N,)`@"```)Q8ET)$")3"08BT0D7(%$)!C<O!N/BWPD+(E<)!R#5"0<`#'2
M`40D&!%4)!R+5"1(QT0D/`````")T8G3">DAZR-,)"`QT@G9`4PD&!%4)!R+
M5"1`BTPD1(G6#ZS.&\'B!0G6BY0D%`(```%T)!B+="08B50D)(ET)#B+="0H
MB?$/K/D"P>8>B?")S@G&BX0D$`(``(GQB?.)]XE$)""!1"0@W+P;CXM$)$B#
M5"0D`#'2`40D(!%4)"0)Z2-,)!`AZXM$)#@QTL=$)"P`````"=D!3"0@$50D
M)(G!BU0D/`^LT1N+5"1$B4PD$(MT)!")P<'A!0G.`70D((M$)"")1"0HBT0D
M0(G!#ZS1`HN4)!@"``")RXN,)!P"``#!X!X)PXE4)!"!1"00W+P;CXE,)!2)
MV8-4)!0`,=(!;"00$50D%`GY(TPD&#'2B5PD2"'[BT0D.(E\)%R)S@G>BUPD
M*`%T)!"+="0L$50D%(G:B=F+G"0D`@``P>$%#ZSR&XG6BU0D/`G.B<$!="00
MBW0D$,'@'@^LT0*)S8N,)"`"```)Q8M$)%R)7"0<B70D0(E,)!B!1"08W+P;
MCX-4)!P`,=+'1"1$``````%$)!@15"0<BU0D2(M\)"S'1"0\`````(G1B=,)
MZ2'K(TPD(#'2"=D!3"08$50D'(M4)$"+3"1$B=8/K,X;P>(%"=:+E"0L`@``
M`70D&(MT)!B)5"0DB70D.(MT)"B)\0^L^0+!YAZ)\(G."<:+A"0H`@``B?&)
M\XGWB40D((M$)$B!1"0@W+P;CX-4)"0`,=(!1"0@$50D)`GI(TPD$"'KBT0D
M.#'2QT0D+``````)V0%,)"`15"0DB<&+5"0\#ZS1&XM4)$2)3"00BW0D$(G!
MP>$%"<X!="0@BT0D((E$)"B+1"1`B<$/K-$"BY0D,`(``(G+BXPD-`(``,'@
M'@G#B50D$(%$)!#<O!N/B4PD%(G9@U0D%``QT@%L)!`15"04"?DC3"08,=*)
M7"1((?N+1"0XB7PD7(G."=Z+7"0H`70D$(MT)"P15"04B=J)V8N<)#P"``#!
MX04/K/(;B=:+5"0\"<Z)P0%T)!#!X!Z+="00#ZS1`HG-BXPD.`(```G%BT0D
M7(E<)!R)="1`B4PD&(%$)!C<O!N/@U0D'``QT@%$)!@15"0<BU0D2,=$)$0`
M````B=&)TPGI(>LC3"0@,=()V0%,)!@15"0<BU0D0(M,)$2+?"0LQT0D)```
M``")U@^LSAO!X@4)UHN4)$0"```!="08BW0D&(E4)"R)="0@BW0D*(GQ#ZSY
M`L'F'HGPB<X)QHN$)$`"``")\8GSB?>)1"0HBT0D2(%$)"C<O!N/@U0D+``Q
MT@%$)"@15"0L">DC3"00(>LQT@G9`4PD*!%4)"R+1"0@BU0D),=$)#P`````
MQT0D'`````")P0^LT1N+5"1$B4PD$(MT)!")P<'A!0G.`70D*(M$)"B)1"0X
MBT0D0(E\)$")P0^LT0+!X!X)P8G.BXPD2`(``(ET)$B)\HMT)!B!P=;!8LH!
MZ3'ZBWPD/#'6BU0D)`'QBW0D.(GP#ZSX&XE$)!")\(MT)!#!X`4)QHM$)"`!
M\8E,)!@/K-`"BY0D5`(``(G'BT0D((G]B50D%,'@'@G%BX0D4`(``(E$)!"!
M1"00UL%BRH-4)!0`,=*+1"1``40D$!%4)!2+5"1(BW0D*(M$)!B);"1`,>HQ
MUC'2`70D$(G&$50D%(M4)!S!X`7'1"0D``````^LUAN+5"0\B?.)W0G%BT0D
M.`%L)!"+="00B70D((G&#ZS6`HM4)$#!X!X)QHM$)$B)]8NT)%@"``");"1(
M@<;6P6+*`<8QZHG5BU0D(#'-BTPD)`'N#ZS*&XM,)"")5"0HBVPD*,'A!0G-
M`>Z)="0HBT0D&(M4)!R+;"1(QT0D+`````")P0^LT0*+E"1D`@``P>`>B<N+
M3"0H"<.+A"1@`@``B50D'(E$)!B+1"1`@40D&-;!8LJ#5"0<`#'2`40D&(G(
M$50D'#'=B>^+;"00,=*)7"1`BUPD+#']`6PD&!%4)!P/K-@;B40D$(G(BTPD
M$,'@!0G!`4PD&(M$)!B)1"0XBTPD((M<)"2+E"1L`@``QT0D/`````")R`^L
MV`*)QXG(P>`>B?D)P8N$)&@"``")5"04B<W'1"0D`````(E$)!"+1"1(@40D
M$-;!8LJ#5"04`#'2`40D$!%4)!2+5"1`BT0D.#'*B=,QTC'SB<8!7"00$50D
M%(M4)#S!X`4/K-8;BU0D+(GSB=D)P8M$)"@!3"00BTPD$(G&#ZS6`HN4)'0"
M``#!X!X)QHN$)'`"``")3"0@B40D*(M$)$"!1"0HUL%BRHM\)"2)5"0L@U0D
M+``QT@%$)"@15"0LB?(QZHET)$"+="0@B=,QTC-<)!@!7"0H$50D+(GR#ZSZ
M&XGQB50D&(MT)!C!X06+5"0\QT0D'`````"+?"0<"<X!="0HBT0D*(MT)!")
M1"08BT0D.(G!#ZS1`HG+BXPD>`(``,'@'@G#B5PD2('!UL%BR@'IBVPD0#'=
M,>X!\8MT)!B)\`^L^!N)1"00B?"+="00P>`%BU0D),=$)#P`````"<:+1"0@
M`?&)3"0X#ZS0`HN4)(0"``")QXM$)"")_HE4)!3!X!X)QHN$)(`"``")1"00
MBT0D0(%$)!#6P6+*@U0D%``QT@%$)!`15"04BU0D2(ET)$"+1"0X,?*+="0H
M,=8QT@%T)!")QA%4)!2+5"0\P>`%#ZS6&XGSB=T)Q0%L)!"+="00B70D((M$
M)!B+5"0<QT0D)`````#'1"0L`````(G&#ZS6`HM4)$#!X!X)QHM$)$B)]8NT
M)(@"``");"1(@<;6P6+*`<8QZHM$)#B)U8M4)"`QS8M,)"0![@^LRAN+3"0@
MB50D&(ML)!B+5"0\P>$%"<V)P0'NBVPD2`^LT0*+E"24`@``P>`>B<L)PXN$
M))`"``")="0HB50D'(E$)!B+1"1`@40D&-;!8LJ#5"0<`#'2`40D&!%4)!PQ
MW8GOBVPD$#'2B5PD0#']`6PD&(M,)"B+7"0L$50D'(N4))P"``")R`^LV!N+
M7"0DB40D$(G(BTPD$,'@!8E4)!3'1"0\``````G!`4PD&(M$)!B+3"0@B40D
M.(G(#ZS8`HG'B<C!X!Z)^0G!BX0DF`(``(G-B40D$(M$)$B!1"00UL%BRH-4
M)!0`,=(!1"00$50D%(M4)$`QRHG3,=(Q\P%<)!`15"04BT0D.(M4)#S'1"0D
M`````(M\)"2)Q@^LUAN+5"0LB?/!X`6)V0G!BT0D*`%,)!"+3"00B<8/K-8"
MBY0DI`(``,'@'@G&BX0DH`(``(E,)"")5"0LB40D*(M$)$"!1"0HUL%BRH-4
M)"P`,=(!1"0H$50D+(GR,>J)="1`BW0D((G3,=(S7"08`5PD*!%4)"R)\@^L
M^AN)\8E4)!B+="08P>$%BU0D/,=$)!P`````BWPD',=$)#P`````"<X!="0H
MBT0D*(MT)!")1"08BT0D.(G!#ZS1`HM4)"2)RXN,)*@"``#!X!X)PXE<)$B!
MP=;!8LH!Z8ML)$`QW3'N`?&+="08B?`/K/@;B40D$(GPBW0D$,'@!0G&BT0D
M(`'QB4PD.`^LT`*+E"2T`@``B<>+1"0@B?Z)5"04P>`>"<:+A"2P`@``B40D
M$(M$)$"!1"00UL%BRH-4)!0`,=(!1"00$50D%(M4)$B)="1`BT0D.,=$)"0`
M````QT0D+``````Q\HMT)"@QUC'2`70D$(G&$50D%(M4)#S!X`4/K-8;BU0D
M'(GSB=T)Q8M$)!@!;"00BW0D$(ET)"")Q@^LU@*+5"1`P>`>"<:+1"1(B?6+
MM"2X`@``B6PD2('&UL%BR@'&,>J+1"0XB=6+5"0@,<V+3"0D`>X/K,H;BTPD
M((E4)!B+;"08BU0D/,'A!0G-B<$![@^LT0*+E"3$`@``P>`>B<L)PXN$),`"
M``")="0HB40D&(ML)$B!1"08UL%BRHM$)$")5"0<BTPD*(-4)!P`,=(!1"08
M$50D'#'=B>^+;"00,=*)7"1<BUPD+(G(QT0D/``````Q_0%L)!@15"0<#ZS8
M&XM<)"2)1"00B<B+3"00P>`%BY0DS`(```G!`4PD&(M$)!B+3"0@B40D.(G(
M#ZS8`HG'B<C!X!Z)^0G!BX0DR`(``(G-B40D$(M$)$B!1"00UL%BRHE4)!2#
M5"04`#'2`40D$!%4)!2+5"1<BT0D.,=$)$0`````,<J)TS'2,?.)Q@%<)!`1
M5"04BU0D/,'@!0^LUAN+5"0LB?.)V0G!BT0D*`%,)!"+3"00B<8/K-8"BY0D
MU`(``,'@'@G&BX0DT`(``(E,)$")5"0DB40D((%$)"#6P6+*@U0D)``QTHM$
M)%P!1"0@$50D)(GRBWPD1#'JB70D*(MT)$")TS'2,UPD&`%<)"`15"0DB?(/
MK/H;B?&)5"08BW0D&,'A!8M4)#S'1"0<`````(M\)!P)S@%T)""+1"0@BW0D
M$(E$)!B+1"0XB<$/K-$"BU0D*(G+BXPDV`(``,'@'@G#B5PD.('!UL%BR@'I
M,=HQU@'QBW0D&(GP#ZSX&XE$)!")\(MT)!#!X`4)Q@'QB4PD$(M$)$"+5"1$
MBWPD'(MT)!B)P0^LT0*)S8GYP>D"B?(/K/H"B4PD1(GYB50D0`^D\1Z)\L'@
M'HMT)"#!XAX)Q8M$)"B)3"1,BXPDX`(``(E4)$B+5"0XQT0D%`````");"08
M@<'6P6+*`<&+1"00,>HQUHM4)!0!\8G&#ZS6&XG7B70D((ML)"")QL'F!<'O
M&XE\)"0)]8MT)!`!Z8ML)$")R(M,)%@#1"0P`S0D"VPD2(D!B7$(B>@#1"0(
MQT$$`````,=!#`````")01"+1"08`T0D4,=!%`````#'01P`````B4$8BT0D
M.`-$)&#'020`````B4$@@<3L`@``6UY?7<.-="8`55=6B<93@^PLA<")5"0<
M=$NA0$$%"(7`B40D&'0^#[8&/#UU0S';BT0D&(LHA>UT*XG'D(UT)@")7"0(
MB70D!(DL).CXT/__A<!U!X!\'0`]="V#QP2++X7M==R#Q"PQP%M>7UW#9I"$
MP'2YB?.#PP$/M@,\/70$A,!U\BGSZZ>+1"0<B?DK3"08P?D"B0B#Q"R-1!T!
M6UY?7<.0C70F`%.)PX/L&(U4)`R)V.A/____A<!T-HUV`*%`004(BU0D#(T4
MD(M*!(7)B0ITV8UV`(/"!(M*!(7)B0IU](U4)`R)V.@9____A<!US8/$&%O#
M55>)QU8QP%.)TX/L/(`Z/0^4P`'#B1PDZ(/.__^-5"0LB<6)^.CF_O__A<")
MQ@^$W````(D$).ADSO__.<4/AK0```"+1"0LC0R%``````^V!SP]#X1F`0``
MA,`/A%X!``")^.L&9I"$TG0+@\`!#[80@/H]=?$I^(LU0$$%"(U$*`*)!"0!
MSNBCS?__A<")!@^$/`$``*%`004(C4\!BU0D+(L4D`^V!X3`B`)U&>L;C;0F
M`````(/!`0^V0?^#P@&$P(@"=`0\/77LQ@(],<"-M"8`````#[8,`XA,`@&#
MP`&$R77Q,<"#Q#Q;7E]=PXVT)@````"#PP$/MD/_@\8!A,"(1O]U[^O<D(UT
M)@"+%4!!!0B+`H7`#X2G````,?:-M@````"#Q@&+!+*%P'7VC02U"````(L-
M8%$%"(7)="V)1"0$B10DZ-',__^%P*-`004(='N-#+4`````QT2P!`````")
M="0LZ=_^__^)!"2)5"08QP5@404(`0```.BJS/__A<!T28M4)!B-#+4`````
MB4PD"(D$)(E,)!R)5"0$B40D&.@3R___BT0D&(M,)!RC0$$%".NCC70F`#'`
MZ;+^__^X"````#'VZ6;___^X_____^D,____C78`55=6B<93@>R,````A<!T
M!8`X`'4+@<2,````6UY?7<.)!"3HJ,[__X7`B<=TYXD\).@*SO__A<")PP^$
ML````(![$RX/A,8```")-"2-:Q/H:\S__XDL)(E$)!SH7\S__XM,)!R-1`$"
MB00DZ-_+__^);"04B70D$,=$)`Q`Y@0(QT0D"/_____'1"0$`0```(D$)(G#
MZ$7.__^-1"0@B40D"(E<)`3'!"0#````Z,W-__^#^/]T$(M$)#`E`/```#T`
M0```='")'"3HL,K__XD<).@8RO__B3PDZ&#-__^%P(G##X56____C;8`````
MB3PDZ,C-__^)-"3H,,K__X'$C````%M>7UW#D(UT)@`/MD,4A,`/A!+___\\
M+@^%)O___X![%0`/A`#___]FD.D5____C78`B=CHP?[__Y#KCHVT)@````"-
MO"<`````5E.#[!2A2$$%"(D$).@NS?__BT!XBW`$H4A!!0B)!"3H&\W__P^V
M6&6A2$$%"(/C?XD$).@'S?__BT`$#[=`$,'@!PG89HE&`J%(004(B00DZ.K,
M__^+0'B+6`2A2$$%"(D$).C7S/__QT0D"`````#'1"0$'^@$"(D$).@?R___
MB4,<H4A!!0B)!"3HK\S__XM`>(M8!*%(004(B00DZ)S,__^+@`@$``")0R"A
M2$$%"(D$).B&S/__BT!XBU@$H4A!!0B)!"3H<\S__S'2BX`D`0``A<!T%J%(
M004(B00DZ%K,__^+@"0!``"+4'"A2$$%"(E3)(D$).A!S/__BT!XBT`$QT`H
M`````*%(004(B00DZ"?,__^+0'B+0`3'0!@`````H4A!!0B)!"3H#<S__XM`
M>(M8!*%(004(B00DZ/K+__^+@#`"``")0RR#Q!1;7L.-="8`C;PG`````%.)
MPX/L&*%(004(B00DZ,W+__^)7"0$QP0D`P````4P`0``B40D".C$R___A<!T
M"(/$&#'`6\.0H4A!!0B)!"3HF\O__XN`0`$``"4`\```/0!```!T'Z%(004(
MB00DZ'S+__^+@$`!```E`/```#T`H```=;J)'"3'1"0$`@```.B:RO__A<`/
ME,"#Q!@/ML!;PXVV`````(V\)P````!5B=57B<=64X'L+!```(UT)!S'1"0(
M_P\``(ET)`3'!"1&Y@0(9:$4````B80D'!```#'`Z"?(__^%P'YKC5C_@'P<
M'`!T68G#B5PD",=$)`0O````B30DZ,/)__^%P'1'H4A!!0B)!"3HTLK__XE<
M)`R)="0(B7PD!(D$).A.RO__BX0D'!```&4S!10```!U-8'$+!```%M>7UW#
MC78`A=MUI8UT)@"A2$$%"(D$).B+RO__B6PD"(E\)`2)!"3HJ\?__^N[Z$3'
M__^-="8`@^P<H4A!!0B)!"3H8,K__\=$)`Q5Y@0(QT0D"%"3!`C'1"0$7^8$
M"(D$).C`R/__@\0<PXVV`````(V_`````(/L+*%(004(B00DZ"#*__^)!"3H
MJ/___Z%(004(B00DZ`O*___'1"04`````,=$)!`?Z`0(QT0D#!_H!`C'1"0(
MH.`$",=$)`1[Y@0(B00DZ`O)__^#Q"S#C;0F`````%=64X'L,"```&6A%```
M`(F$)"P@```QP(U<)"KH/\?__\=$)!11Y@0(QT0D#)#F!`C'1"0(`1```,=$
M)`0!````B1PDB40D$.C3R?__A<!X9XV\)"L0``")'"3'1"0(`!```(E\)`3H
MA,;__X7`B<-X1HU``8D$).@3Q___A<")QG0UB5PD"(E\)`2)!"3HK<7__XGP
MQ@0>`(N4)"P@``!E,Q44````=1.!Q#`@``!;7E_#D(UT)@`QP.O=Z-_%___K
M#9"0D)"0D)"0D)"0D)#I*____XUT)@"-O"<`````55=64X'L/!```&6A%```
M`(F$)"P0```QP(U4)"BXGN8$"(NT)%`0``"+O"14$```Z%OW___'1"0$+P``
M`(DT)(G#Z+G&__^%P'0MB?*XI^8$".@I^/__B?"+C"0L$```93,-%`````^%
M5@$``('$/!```%M>7UW#B30DZ*#&__^)/"2-?"0LQT0D!+3F!`B)1"0<Z+C'
M__^)Q8M$)!R#P`&)1"0<C78`A>UTGX!]``"XG.8$"`]$Z(7;=!2);"0$B1PD
MZ$C$__^%P`^$JP```(DL).A(QO__@'P%_R]U$)"#Z`&`?`7_+\9$!0``=/&+
M3"0<C10!@?K_#P``#X])____B70D&,=$)!2VY@0(B6PD$,=$)`S:YP0(QT0D
M"``0``#'1"0$`0```(D\).@.R/__H4A!!0B)!"3HL<?__XE\)`3'!"0#````
M!3`!``")1"0(Z(C'__^%P'4?H4A!!0B)!"3HA\?__XN`0`$``"4`\```/0"`
M``!T&\=$)`2TY@0(QP0D`````.C!QO__B<7I$O___\=$)`0!````B3PDZ(K&
M__^%P'71B?JXI^8$".C*]O__B3PDZ.+%___IEO[__^CXP___D(VT)@````"+
M1"0$#[8(A,ET%8U0`6:0@/DO#[8*#T3"@\(!A,EU\//#C;0F`````(V\)P``
M``!3@^P8BUPD((7;=#R`.P!T-XD<).@'Q?__C40#_SG#<@[K49"-="8`@^@!
M.=AT"8`X+W3TZS=FD(`X+Y"-="8`#X6)````9I#'!"0"````Z%S$__^%P'1P
MNBX```!FB1"#Q!A;PXUV`(`X+W0'@^@!.<-R]#G8=0WKOHVV`````(`X+W4'
M@^@!.<-R]"G8C5`"@?H`$```=R^#P`&)7"0$QT0D#``0``")1"0(QP0D8$$%
M".A(Q?__@\08N&!!!0A;PXVV`````(/$&#'`6\/'1"0@MN8$"(/$&%OIP,3_
M_U=6@^PT9:$4````B40D+#'`H2SH!`B)1"0*H3#H!`B)1"0.H33H!`B)1"02
MH3CH!`B)1"06H3SH!`B)1"0:H4#H!`B)1"0>H43H!`B)1"0BH4CH!`B)1"0F
M#[<%3.@$"&:)1"0JN+CF!`CHX?3__[C!Y@0(Z-?T__^XR>8$".C-]/__N-+F
M!`CHP_3__[C9Y@0(Z+GT__^XZ>8$".BO]/__N)[F!`CHI?3__[CUY@0(Z)OT
M__^X_^8$".B1]/__N`GG!`CHA_3__[BGY@0(Z'WT__^X$^<$".AS]/__N!SG
M!`CH:?3__XU4)`2X)^<$".B[\___A<!T#(G"N/_F!`CHF_3__XU4)`2X..<$
M".B=\___A<!T#(G"N$KG!`CH??3__XU4)`2X5><$".A_\___A<!T,XG"N)[F
M!`CH7_3__[J!YP0(N-GF!`CH4/3__XM$)"QE,P44````=4V#Q#1>7\.0C70F
M`(U4)`2X9><$".@Z\___A<!T#HG"N/7F!`CH&O3__^NYC70D&[]VYP0(N0H`
M``#SIG6GC50D);CUY@0(Z/CS___KE^@QP?__D*$H004(@_C_=`;#D(UT)@"#
M[!RX]>8$"(U4)`SHW_+__X7`=!L/MA`QP(32=`@QP(#Z,`^5P*,H004(@\0<
MPY`QP.ORC;8`````C;\`````@^P<Z.C`__^)!"3H0,#__X7`=`R+`(/$',.-
MM@`````QP.ORC;8`````C;\`````55>_C><$"%93NX/G!`B#[$S'1"0DC><$
M"(UT)"S'1"0H@^<$",=$)"R0YP0(QT0D,(;G!`C'1"0TB^<$",=$)#B=YP0(
MQT0D/`````#K(I"+1"1@B2PDB40D!.B0O___A<!T/(7;="Z+!HG?@\8$B<.-
M5"0@B?CH!/+__X7`B<5T!8`X`'7)BU0D8(GXZ-[R__^%VW72@\1,6UY?7<-F
MD(M$)&")!"3H9,'__XDL)(E$)!SH6,'__XM4)!R-1`("B00DZ-C`__^);"08
MQT0D%+3F!`C'1"0,VN<$",=$)`C_____QT0D!`$```")PHM$)&")%"2)5"0<
MB40D$.@NP___BU0D'(GXZ&/R___I4O___XVT)@````"-O"<`````55=64X'L
M3($``&6A%````(F$)#R!```QP(U4)$RXGN8$"(NL)&"!``#'1"10M.<$",=$
M)%2<Y@0(QT0D6`````#'1"1H2N<$",=$)&Q#YP0(QT0D<+GG!`C'1"1T8.<$
M",=$)'C!YP0(QT0D?`````#'1"1<J.<$",=$)&#%YP0(QT0D9`````#HTO#_
M_X7`=`F`.``/A64$``"0C70F`.@+_O__A<")PP^$;@0``(D<).@YP/__C40`
M`8D$).B]O___@#L`B<:)QW0VC70F``^V`X/#`8D\)(/'`L=$)`S.YP0(QT0D
M"/____^)1"00QT0D!`$```#H$\+__X`[`'7.C7PD;+A*YP0(ZPV-=@"#QP2+
M1_R%P'0NC50D3.@]\/__A<")PW3G@#@`=.+HK?7__X7`=-F)'"3H,<#__X7`
MB<%U38UV`(M<)%"%VW1`@#L`OP$```!U%NLTC70F`(M<O%"%VW0H@\<!@#L`
M="")V.AI]?__A<!TY8D<).CMO___A<!TV8G!ZP>0C70F`#')B0PDB?.)3"0L
MZ%"___^+3"0LBSN#PP2-E__^_O[WUR'Z@>*`@("`=.F)U\'O$/?"@(````]$
MUXU[`@]$WP#2@]L#*?.-G`,$!```B1PDB4PD,.B7OO__BTPD,(ET)!S'1"08
MT^<$",=$)!2VY@0(B4PD$,=$)`S8YP0(B<;'1"0(_____\=$)`0!````B00D
MB40D+.CEP/__QT0D!,`!``")-"3H);___X/X_P^$A````*%(004(B00DZ&_`
M___'!"0#````!3`!``")1"0(BT0D+(E$)`3H8L#__X7`#X2:````BT0D+(E$
M)!"+10#'1"0(C.@$",=$)`0!````B40D#*%$004(B00DZ-Z___\QP(N,)#R!
M``!E,PT4````#X78"0``@<1,@0``6UY?7<.0C70F`.C#OO__BP"#^!$/A&S_
M__^)1"04BT0D+(E$)!"+10#'1"0(4.@$",=$)`0!````B40D#*%$004(B00D
MZ'B___\QP.N8C70F`*%(004(B00DZ*.___^+@$`!```E`/```#T`0```#X5#
M____H4A!!0B)!"3H@+___XNP2`$``.A5O/__.<8/A2/___^A2$$%"(D$).A@
MO___BX!``0``)?\!```]P`$```^%`/___XD<).@"O?__C50D3(E$)#BXAN<$
M".C0[?__A<`/A/T(``")!"3HT+W__XE$)`2+10")!"3H(?;__X7`B<,/A-P(
M``")'"3H+[W__X/X`WXJC70#_+_AYP0(N04```#SIG48@_@$#X2G!P``@'P#
M^R\/A)P'``"-="8`Z&OZ__^%P'4<QT0D!`````")'"3H![W__X7`B40D,`^%
M5P$``+J!YP0(N/7F!`CH+.[__S';Z"6\__^+?"0LBW0D.,=$)!P?Z`0(QT0D
M%+;F!`B)?"00QT0D#/KG!`B)1"08QT0D"/_____'1"0$`0```(DT).BEOO__
MZU&-=@#H&[W__X,X$759Z-&[__^#PP''1"0@'^@$"(E<)!S'1"04MN8$"(E\
M)!#'1"0,".@$"(E$)!C'1"0(_____\=$)`0!````B30DZ%*^___'1"0$P`$`
M`(DT).B2O/__@_C_=)V+1"0LB00DZ$&Z__^+="0XN)[F!`B)\NAA[?__B30D
MZ.GY__^)\.FF_?__9I")!"2)1"0LZ-3Y__^+1"0LB00DZ%B\___IA_W__[BH
MYP0(O@$```#K$HVT)@````"+1+1<@\8!A<!T)8U4)$SH'.S__X7`=.B`.`!T
MXXD$).@;O/__A<!TUXG#Z4_[__^P#;NMYP0(Z4_[___'1"0,`@```(G&QT0D
M!.[____'1"0(_____XD$).BRNO__C80D/`$``,=$)`@&````B40D!(DT).A'
MN?__@+PD/`$```!U#H"\)#T!``!##X1`!@``BT0D,,=$)`P`````QT0D!```
M``#'1"0(`````(D$).A;NO__QX0DP`````$C16?'A"3$`````````,>$),@`
M``")J\WOQX0DS`````````#'A"30````_MRZF,>$)-0`````````QX0DV```
M`'94,A#'A"3<`````````,>$).````#PX=+#QX0DY`````````#'A"3H````
M`````,>$).P`````````QX0D\`````````#'A"3T`````````,>$)#@!````
M````C;8`````C80D/`$``(E$)`2+1"0PQT0D"`"```")!"3H0;C__X7`B<4/
MCA@"``"+A"3H````B>F)[XN4).P```#!X0.)[L'_'P'!@_H`#X?:`0``.<@/
MA](!``"+A"3P````BY0D]````(F,).@```")\8G[#ZSY'<'K'0'!BX0D.`$`
M`!'3QX0D[`````````")C"3P````A<")G"3T````#X1V`0``OD`````IQCGU
M#T[UC80$^````(V,)#P!``")="0(B4PD!(D$).C4M___BX0D.`$```'P@_A`
MB80D.`$```^%&____XV$)#P!```I]0'&C80DP````.ADOO__C70F`(/]/P^.
MX````(/M0(GWB>C!Z`:)1"0\P>`&C5P&0&:0BP>#QT")A"3X````BT?$B80D
M_````(M'R(F$)``!``"+1\R)A"0$`0``BT?0B80D"`$``(M'U(F$)`P!``"+
M1]B)A"00`0``BT?<B80D%`$``(M'X(F$)!@!``"+1^2)A"0<`0``BT?HB80D
M(`$``(M'[(F$)"0!``"+1_")A"0H`0``BT?TB80D+`$``(M'^(F$)#`!``"+
M1_R)A"0T`0``C80DP````.B2O?__.=\/A4K___^+?"0\B?B#P`'!X`;!YP8!
MQBG]C80D^````,=$)`Q$````B6PD"(ET)`2)!"3H"+C__XFL)#@!``#I[/W_
M_XUT)@"-M"0\`0``Z=S^__^-="8`BX0D\````(N4)/0```"#P`&#T@#I(_[_
M_XM$)#")!"3H`[K__XN$)/````"+G"3H````B[0D[````(N4)/0```")1"0P
MB=@/K/`#@^`_B50D-(U0`8/Z.,:$!/@```"`#X^>`@``NC<````IPHV$!/D`
M``")5"0(QT0D!`````")!"3H$+C__XM\)#"+;"0TB)PD-P$``(GX#ZSH&(B$
M)#`!``")^`^LZ!"(A"0Q`0``B?@/K.@(B(0D,@$``(GXB(0D,P$``(G8#ZSP
M&(B$)#0!``")V`^L\!"(A"0U`0``B=@/K/`(B(0D-@$``(V$),````#H/KS_
M_XN$),````"-K"27````BY0DQ````(V\)(0```"+G"3,````B<$/K-$8B<Z(
MC"2#````B<$/K-$0B(PDA````(G!#ZS1"(B,)(4```"+C"3(````B(0DA@``
M`(G(#ZS8&(B$)(<```")R`^LV!"(A"2(````B<B(C"2*````BXPDT`````^L
MV`B+G"34````B(0DB0```(G(#ZS8&(B$)(L```")R`^LV!"(A"2,````B<B(
MC"2.````BXPDV`````^LV`B+G"3<````B(0DC0```(G(#ZS8&(B$)(\```")
MR`^LV!"(A"20````B<B(C"22````BXPDX`````^LV`B+G"3D````B(0DD0``
M`(G(#ZS8&(B$)),```")R`^LV!"(A"24````B<@/K-@(B(0DE0```(V<)+\`
M``")\(B,))8```#I"@```(UT)@`/M@>#QP$/ML")+"2#Q0*)1"00QT0D#,[G
M!`C'1"0(_____\=$)`0!````Z."W__\YW77,QH0DOP````"-A"27````QT0D
M'!_H!`B)1"08BT0D+,=$)!2VY@0(QT0D#.OG!`C'1"0(_____XE$)!"+1"0X
MQT0D!`$```")!"3HC;?__^E+^?__BVT$A>T/A%WX__^)+"3H5;7__X/X`P^&
M3/C__XUT!?R_YN<$"+D%````\Z8/1-WI-/C__[H_````*<*-A`3Y````B50D
M",=$)`0`````B00DZ'*U__^-A"3`````Z`:Z__^-E"3X````N0X````QP(G7
M\ZOI/_W__X"\)#X!``!!#X6R^?__@+PD/P$``$,/A:3Y__^`O"1``0``2`^%
MEOG__X"\)$$!``!%#X6(^?__BW0D,,=$)`P"````QT0D!,;____'1"0(____
M_XDT).CCL___C80D/`$``,=$)`@I````B40D!(DT).AXLO__C80D/`$``,=$
M)!P?Z`0(Z;_^__^-="8`Z/NR__^+70#I'/?__XUV`%575E.#["RA2$$%"(D$
M).@,MO__C50D',9`80&XV>8$".B:Y/__A<!T"8`X,0^$E0(``.C8[___H4A!
M!0B)!"3HV[7__\=$)`P+````QT0D"`$```#'1"0$&>@$"(D$).B+L___A<`/
MA,L```"+0`R#/6A1!0@!BW@8#XZX````,?:[`0```.LQC;0F`````(M%#(E$
M)`2A9%$%"(L$F(D$).B9L?__A<!U?:%H404(@\,!@\8!.=A^<Z%(004(B00D
MZ%FU___'1"0,`````(ET)`B)?"0$B00DZ+&T__^%P'1%BRB+10@E``0@`#T`
M!```=)RA2$$%"(D$).@?M?__QT0D#`(```#'1"0(`````(EL)`2)!"3H0[+_
M_^EQ____C;8`````H6A1!0B-4/\Y\@^$,`$``*%(004(B00DZ-NT___'1"0,
M!````,=$)`@!````QT0D!![H!`B)!"3HB[+__X7`B<-T-8M`#(LPH4A!!0B)
M!"3HH[3__\=$)`@@Z`0(B70D!(D$).B_L?__BT,,BQCV0PI`#X4(`0``H4A!
M!0B)!"3H<[3__\=$)`P$````QT0D"`$```#'1"0$)><$"(D$).@CLO__A<")
MQG0ZC50D'+BGY@0(Z-_B__^%P(G##X1U`0``BT8,BSBA2$$%"(D$).@CM/__
MB5PD"(E\)`2)!"3H0['__Z%(004(B00DZ`:T__^-5"0<QD!A`+B>Y@0(Z)3B
M__^%P(G#HVQ1!0@/A)T```#'1"0$P`$``(D$).AULO__@_@1=`R-4`&#^@$/
MAY`!``"#Q"Q;7E]=PXUT)@"#^`$/CL?^__^[`0```&:0H4A!!0B#PP&)!"3H
MF+/__XE\)`2)!"3H#+#__SD=:%$%"'_<Z9?^__^-M"8`````H4A!!0B)!"3H
M:[/__XE<)`2)!"3H7[+__^G:_O__9I"`>`$`#X1F_?__Z5S]__^0H611!0B)
M!"3H>_#__X7`HVQ1!0@/A.X```"+1@R+/611!0B+&(M#""4`!"``/0`$```/
MA:(```"+0PR)?"0$B00DZ!&P__^)QXM&#(L8BU,(@>(`!"``@?H`!```=5"+
M0PR)1"0(H611!0B)?"0,BP#'!"0$Z00(B40D!.@WL?__C;0F`````*%D404(
MBSB+1@R+&*%(004(B00DZ*>R__^)^HG8Z%[G___IAO[__Z%(004(B00DZ(RR
M___'1"0,`@```,=$)`@`````B5PD!(D$).BPK___ZXBA2$$%"(D$).AALO__
MQT0D#`(```#'1"0(`````(E<)`2)!"3HA:___^DS____QP0DX.@$".BDL/__
MB40D#*%D404(B5PD"(L`QP0D+.D$"(E$)`3HA;#__Y"-="8`5E.#[!2+="0@
MB30DZ`_K__\/M@B)PX3)=!:-4`&-=@"`^2\/M@H/1-J#P@&$R77PZ'OM__^%
MP'0=A?9T&8`^`'04QT0D!-/G!`B)'"3HSJW__SG8=`:#Q!1;7L.#Q!2)\%M>
MZ1CC__^0C;0F`````(/L'*%(004(B00DZ)"Q___'1"0$_____XD$).C@KO__
MH4A!!0B)!"3H<['__\=$)`@`````QT0D!(#)!`B)!"3H*['__X/$',-FD&:0
M9I"04^BJL___@<.*6@``@^P8BX,D`0``B40D#(M$)"B)1"0(BT0D)(E$)`2+
M1"0@B00DZ(NN__^#Q!A;PV:09I!FD%57,?]64^AEL___@<-%6@``@^P<BVPD
M,(VS_/[__^C%K/__C8/X_O__*<;!_@*%]G0GC;8`````BT0D.(DL)(E$)`B+
M1"0TB40D!/^4N_C^__^#QP$Y]W7?@\0<6UY?7</K#9"0D)"0D)"0D)"0D)#S
MPP``4X/L".CSLO__@</360``@\0(6\,#`````0`"`"5S+R5S`"]P<F]C+W-E
M;&8O97AE`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$52
M3$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"
M04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"4$%4
M2`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%5315(`4UE35$5-`"]T
M;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A
M<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP
M+25U+25U)7,`05)'5@`8`'!E<FP`+64`+2T``%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N86)L92!T;R!C<F5A=&4@
M8V%C:&4@9&ER96-T;W)Y`````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T
M;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO
M=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD
M)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA
M;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD
M(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO
M<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I
M;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A
M<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD
M("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!
M4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.
M5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L
M971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["G-E96L@7T9(+"`M
M."P@,CL*<F5A9"!?1D@L("1B=68L(#@["FQA<W0@=6YL97-S("1B=68@97$@
M(EQN4$%2+G!M7&XB.PIS965K(%]&2"P@+3$R+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR
M96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN
M9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E
M*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W
M-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY
M("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*
M;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D
M;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E
M96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L
M("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[
M"FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N
M86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D
M;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE
M(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I
M9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%2
M1U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%
M3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N
M=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM
M;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E
M;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`]('-O<G0@>PIL96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"GT@9W)E<"![
M"B$O0E-$4$%.+PI](&=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S
M.PHO7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K
M97ES("4Z.CL*)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N
M.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I
M;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*
M?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL
M92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D
M97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F
M("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D
M:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O
M;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA
M;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q
M+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T
M.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F
M:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T
M>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@
M/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C
M:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M
M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%
M3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*
M)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I
M9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@
M*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E
M9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER
M92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"G-U8B!?<V5T
M7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T
M=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z
M7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@
M)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I
M;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U
M<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-9
M4U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]
M("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X
M+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F
M+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q
M+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T
M.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F
M:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE
M;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]($!?
M.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T96UP
M+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I
M;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N
M86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M
M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#
M($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]
M*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H
M)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#
M3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@````````"`____ST$!&P,[Z````!P```!`;?__!`$``*!Q
M__^<!0``<'3__R@!``#@G___:`$``("@__^\`0``T*#__^`!``"PHO__(`(`
M``"D__]X`@``8*7__Z0"````IO__T`(``-"F__\0`P``$*?__R@#``!PI___
M0`,``$"H__]X`P``4*C__XP#```@JO__S`,``%"J___@`P``,*O__R`$``#@
MK/__4`0``#"M__]L!```8*W__X@$``"`KO__R`0``""[__\,!0``,+___TP%
M``"@O___A`4``/"____(!0``,,#__^@%``"@P/__)`8``!0``````````7I2
M``%\"`$;#`0$B`$``"`````<````-&S__V`$````#@A&#@Q*#PMT!'@`/QH[
M*C(D(CP```!`````0'/__VPK````00X(A0)##@R'`T$.$(8$00X4@P5&#H`&
M`ULK#A1!PPX00<8.#$''#@A!Q0X$``!0````@````'">__^;`````$$."(4"
M00X,AP-!#A"&!$,.%(,%0PY``E8*#A1#PPX00<8.#$''#@A!Q0X$0PMJ#A1%
MPPX00<8.#$''#@A!Q0X$```@````U````+R>__]0`````$$."(,"10X@`D@.
M"$'##@0````\````^````.B>___=`0```$$."(4"00X,AP-##A"&!$,.%(,%
M10Y0`M\*#A1!PPX00<8.#$''#@A!Q0X$2`L`5````#@!``"(H/__0@$```!!
M#@B%`D$.#(<#00X0A@1##A2#!48.H`%/"@X40<,.$$'&#@Q!QPX(0<4.!$$+
M`N8*#A1!PPX00<8.#$''#@A!Q0X$1@L``"@```"0`0``@*'__U4!````00X(
MA@)!#@R#`T,.(`--`0X,0<,."$'&#@0`*````+P!``"THO__DP````!!#@B#
M`D4.(&T*#@A#PPX$0@L"5@X(1,,.!``\````Z`$``"BC___,`````$$."(4"
M0PX,AP-##A"&!$$.%(,%1@[`(`**"@X40<,.$$'&#@Q!QPX(0<4.!$0+%```
M`"@"``"XH___-`````!##B!P#@0`%````$`"``#@H___60````!##C`"50X$
M-````%@"```HI/__P0````!!#@B'`D$.#(8#00X0@P1&#L!``J8*#A!!PPX,
M0<8."$''#@1&"P`0````D`(``,"D__\%`````````#P```"D`@``O*3__\@!
M````00X(A0)!#@R'`T$.$(8$00X4@P5&#M`@`FD*#A1!PPX00<8.#$''#@A!
MQ0X$00L0````Y`(``$RF__\B`````````#P```#X`@``:*;__^``````00X(
M@P)##B`"7PH."$'##@1$"P)3"@X(1L,.!$<+0PH."$/##@1!"TL."$'##@0L
M````.`,```BG__^O`0```$$."(<"00X,A@-##D`#6P$*#@Q!Q@X(0<<.!$8+
M```8````:`,``(BH__]$`````%,.(&L*#@1""P``&````(0#``"\J/__)```
M``!##B!6"@X$1PL``#P```"@`P``T*C__Q(!````00X(A0)!#@R'`T8.$(8$
M00X4@P5(#F`"B`H.%$'##A!!Q@X,0<<."$'%#@1#"P!`````X`,``+"I__^=
M#````$$."(4"00X,AP-!#A"&!$$.%(,%1@[@@@(#M`(*#A1!PPX00<8.#$''
M#@A!Q0X$1@L``#P````D!```#+;__PL$````00X(A0)!#@R'`T$.$(8$00X4
M@P5##D`#6`(*#A1!PPX00<8.#$''#@A!Q0X$10LT````9`0``-RY__]H````
M`$$."(8"00X,@P-##B`"5`H.#$'##@A!Q@X$00M##@Q#PPX(0<8.!!0```"<
M!```%+K__TD`````0PX@`D4.!"@```"T!```_&O__]P!````00X(A0)"#05(
MA@.#!`.``0K#0<9!Q0P$!$$+'````.`$```@NO__.@````!!#@B#`DX.(&D.
M"$'##@0X``````4``$"Z__]A`````$$."(4"00X,AP-##A"&!$$.%(,%3@XP
M`D@.%$'##A!!Q@X,0<<."$'%#@00````/`4``'2Z__\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#`F00(H)D$"``````!`````0````$````-`@``
M`0```%P"```,````F)($"`T````DY@0(&0```/@^!0@;````!````!H```#\
M/@4('`````0```#U_O]OK($$"`4```"TB00(!@````2#!`@*````+`4```L`
M```0````%0`````````#`````$`%"`(````H`@``%````!$````7````<)`$
M"!$```!(D`0($@```"@````3````"````/[__V^XCP0(____;P(```#P__]O
MX(X$"```````````````````````````````````````````````````````
M```````````````$/P4(``````````#6D@0(YI($"/:2!`@&DP0(%I,$"":3
M!`@VDP0(1I,$"%:3!`AFDP0(=I,$"(:3!`B6DP0(II,$"+:3!`C&DP0(UI,$
M".:3!`CVDP0(!I0$"!:4!`@FE`0(-I0$"$:4!`A6E`0(9I0$"':4!`B&E`0(
MEI0$"*:4!`BVE`0(QI0$"-:4!`CFE`0(]I0$"`:5!`@6E00()I4$"#:5!`A&
ME00(5I4$"&:5!`AVE00(AI4$"):5!`BFE00(MI4$",:5!`C6E00(YI4$"/:5
M!`@&E@0(%I8$"":6!`@VE@0(1I8$"%:6!`AFE@0(=I8$"(:6!`B6E@0(II8$
M"+:6!`C&E@0(UI8$".:6!`CVE@0(!I<$"!:7!`@``````````/____]PZ00(
M1T-#.B`H56)U;G1U(#0N."XS+31U8G5N='4R*2`T+C@N,P!'0T,Z("A58G5N
M='4@-"XX+C,M,W5B=6YT=3,I(#0N."XS```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F
M<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ
M8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT
M```````````````````````````````````````````````````````+````
M`0````(```!4@00(5`$``!,```````````````$`````````$P````<````"
M````:($$"&@!```@```````````````$`````````"$````'`````@```(B!
M!`B(`0``)```````````````!``````````T````]O__;P(```"L@00(K`$`
M`%@!```%``````````0````$````/@````L````"````!(,$"`0#``"P!@``
M!@````$````$````$````$8````#`````@```+2)!`BT"0``+`4`````````
M`````0````````!.````____;P(```#@C@0(X`X``-8````%``````````(`
M```"````6P```/[__V\"````N(\$"+@/``"0````!@````(````$````````
M`&H````)`````@```$B0!`A($```*`````4`````````!`````@```!S````
M"0```$(```!PD`0(<!```"@"```%````#`````0````(````?`````$````&
M````F)($")@2```C```````````````$`````````'<````!````!@```,"2
M!`C`$@``8`0`````````````$`````0```""`````0````8````@EP0((!<`
M``)/`````````````!``````````B`````$````&````).8$""1F```4````
M```````````$`````````(X````!`````@```#CF!`@X9@``2#\`````````
M````"`````````"6`````0````(```"`)04(@*4``.P```````````````0`
M````````I`````$````"````;"8%"&RF``!0!0`````````````$````````
M`*X````.`````P```/@^!0CXK@``!```````````````!`````````"Z````
M#P````,```#\/@4(_*X```0```````````````0`````````Q@````$````#
M`````#\%"`"O```$```````````````$`````````,L````&`````P````0_
M!0@$KP``^`````8`````````!`````@```#4`````0````,```#\/P4(_*\`
M``0```````````````0````$````V0````$````#`````$`%"`"P```@`0``
M```````````$````!````.(````!`````P```"!!!0@@L0``$```````````
M````!`````````#H````"`````,```!`004(,+$``#00`````````````"``
M````````[0````$````P`````````#"Q``!&```````````````!`````0``
I``$````#``````````````!VL0``]@```````````````0``````````
